# aroundme

**aroundme** is a basic utility that lets you find interesting places around you just by providing the kind of place you are looking for.

You can take a look at the code on my [github](https://github.com/rishabh570/aroundme).

## Installation

You can install this package from [PyPi](https://pypi.org/):

`pip install aroundme`

## How to Use

You can just run `aroundme` to get a list of hotels around you, you can provide what you're looking for though. Take a look at `aroundme --help` to see the help message.

